@@ -10,7 +10,7 @@ import wsgi_intercept
 import httplib2
 import simplejson
 
-from fixtures import muchdata, reset_textstore, teststore
+from fixtures import muchdata, reset_textstore, _teststore
 
 text_put_body=u"""modifier: JohnSmith
 created: 
@@ -30,8 +30,8 @@ def setup_module(module):
     httplib2_intercept.install()
     wsgi_intercept.add_wsgi_intercept('our_test_domain', 8001, app_fn)
 
-    module.store = teststore()
     reset_textstore()
+    module.store = _teststore()
     muchdata(module.store)
 
 def test_put_tiddler_txt_1():
