@@ -26,4 +26,9 @@ extensibility.
 The primary resources presented by the server are Recipes,
 Bags and Tiddlers. See the tiddlyweb.model package.
 """
-__version__ = '0.9.33'
+__version__ = '0.9.35'
+__author__ = 'Chris Dent (cdent@peermore.com)'
+__copyright__ = 'Copyright UnaMesa Association 2008-2009'
+__contributors__ = ['Frederik Dohr',
+        'Zac Bir']
+__license__ = 'BSD'
